summaryrefslogtreecommitdiff
path: root/src/progs/manaplus/client.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/progs/manaplus/client.cpp')
-rw-r--r--src/progs/manaplus/client.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/progs/manaplus/client.cpp b/src/progs/manaplus/client.cpp
index d8ba7e1c2..355a91602 100644
--- a/src/progs/manaplus/client.cpp
+++ b/src/progs/manaplus/client.cpp
@@ -1,10 +1,10 @@
/*
* The ManaPlus Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -311,7 +311,7 @@ void Client::gameInit()
else
{
settings.logFileName = pathJoin(settings.localDataDir,
- "manaplus.log");
+ "manaverse.log");
}
logger->log("Log file: " + settings.logFileName);
logger->setLogFile(settings.logFileName);
@@ -1,10 +1,10 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
@@ -1,10 +1,10 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify